import java.applet.*;
import java.awt.*;

public class EX15A extends Applet implements Runnable
{
	protected ImageCanvas Images[];
	protected MediaTracker ImageTracker;
	protected Thread ImageThread;

	public void init()
	{
        // If you use a ResourceWizard-generated "control creator" class to
        // arrange controls in your applet, you may want to call its
        // CreateControls() method from within this method. Remove the following
        // call to resize() before adding the call to CreateControls();
        // CreateControls() does its own resizing.
        //----------------------------------------------------------------------
		resize(500, 300);

		// create a tracker to monitor image loading
		ImageTracker = new MediaTracker(this);

		// create a place to put the image controls
		Images = new ImageCanvas[3];

		// add the images to be tracked
		for (int index = 0; index < 3; index++) {
			Images[index] = new ImageCanvas(ImageTracker, 
					getImage(getCodeBase(),
					"images\\Christopher" + 
					Integer.toString(index + 1) + ".jpg"));
			add(Images[index]);
		}
	}

	public void start()
	{
		if (ImageThread == null) {
			ImageThread = new Thread(this);
			ImageThread.start();
		}
	}
	
	public void stop()
	{
		if (ImageThread != null) {
			ImageThread.stop();
			ImageThread = null;
		}
	}

	public void run()
	{
		// wait for all of the images to be loaded
		for (int index = 0; index < 3; index++)
			Images[index].WaitForImage();
	}
}

class ImageCanvas extends Canvas
{
	// NextImageId is used to give each image a unique id
	protected static int NextImageId = 1;

	protected MediaTracker ImageTracker;
	protected Image TheImage;
	protected int LocalImageId;
	protected boolean ImageIsLoaded = false;
	protected boolean LoadError = false;


	ImageCanvas(MediaTracker ImageTracker, Image TheImage)
	{
		// use the next available image id and increment the next id
		LocalImageId = NextImageId;
		NextImageId++;

		// save the passed in info
		this.ImageTracker = ImageTracker;
		this.TheImage = TheImage;

		// resize the canvas to a known size
		resize(200, 140);

		// add the image to the media tracker
		ImageTracker.addImage(TheImage, LocalImageId, 
				size().width, size().height);
	}

	public void paint(Graphics g)
	{
		if (ImageIsLoaded) {
			if (LoadError)
				g.drawString("Error loading image.", 10, 10);
			else
				g.drawImage(TheImage, 0, 0, this);
		}
		else {
			g.drawString("Loading", 10, 10);
		}
	}

	public void WaitForImage()
	{
		try {
			ImageTracker.waitForID(LocalImageId);
		}
		catch (InterruptedException e) {}

		// set state flags
		ImageIsLoaded = true;
		LoadError = ImageTracker.isErrorID(LocalImageId);

		// force the component to be updated
		repaint();
	}
}